Header menu logo CodecMapper

ResizableBuffer Type

Growable in-memory byte buffer used by the built-in codecs.

Record fields

Record Field Description

InternalCount

Full Usage: InternalCount

Field type: int
Modifiers: mutable
Field type: int

InternalData

Full Usage: InternalData

Field type: byte[]
Modifiers: mutable
Field type: byte[]

ReturnToPool

Full Usage: ReturnToPool

Field type: bool
Modifiers: mutable
Field type: bool

Instance members

Instance member Description

this.Release

Full Usage: this.Release

Benchmarks and serializers should always return pooled storage after materializing the final string so hot-path allocation stays low.

Static members

Static member Description

ResizableBuffer.Create(initialCapacity)

Full Usage: ResizableBuffer.Create(initialCapacity)

Parameters:
    initialCapacity : int

Returns: ResizableBuffer

Creates a new buffer with the requested initial capacity.

initialCapacity : int
Returns: ResizableBuffer

Type something to start searching.